@@ -5,6 +5,7 @@ Version 0.31"""
 
 import sys
 import os
+import subprocess
 import pickle
 import datetime
 import time
@@ -33,6 +34,7 @@ alarm_type = "Alarm"
 dbus_type = "Dbus call"
 exec_type = "Command execution"
 builtin_type = "Built-in function"
+profile_type = "Switch profile"
 # days of week
 mon = "Monday"
 tue = "Tuesday"
@@ -45,8 +47,6 @@ sun = "Sunday"
 gprsdataresetter = "Reset GPRS data counter"
 offlineswitcher = "Enable flight mode"
 onlineswitcher = "Disable flight mode"
-silentprofile = "Set 'silent' profile"
-generalprofile = "Set 'general' profile"
 
 class DataCounterResetter(QtGui.QWidget):
     def __init__(self, parent=None):
@@ -104,6 +104,7 @@ class DataCounterResetter(QtGui.QWidget):
         #~ self.typePicker.addItem(dbus_type)
         self.typePicker.addItem(exec_type)
         self.typePicker.addItem(builtin_type)
+        self.typePicker.addItem(profile_type)
         self.connect(self.typePicker, QtCore.SIGNAL("activated(int)"),
                      self.updateInputField)
         
@@ -160,8 +161,7 @@ class DataCounterResetter(QtGui.QWidget):
         self.eventBuiltin.addItem(gprsdataresetter)
         self.eventBuiltin.addItem(offlineswitcher)
         self.eventBuiltin.addItem(onlineswitcher)
-        self.eventBuiltin.addItem(silentprofile)
-        self.eventBuiltin.addItem(generalprofile)
+        self.eventProfile = QtGui.QComboBox()
         self.eventDbusInterface.hide()
         self.eventDbusService.hide()
         self.eventDbusPath.hide()
@@ -169,6 +169,7 @@ class DataCounterResetter(QtGui.QWidget):
         self.eventDbusArgs.hide()
         self.eventExec.hide()
         self.eventBuiltin.hide()
+        self.eventProfile.hide()
         
         self.addButton = QtGui.QPushButton("Add")
         self.connect(self.addButton, QtCore.SIGNAL("clicked()"),
@@ -191,6 +192,7 @@ class DataCounterResetter(QtGui.QWidget):
         inputField2HBox.addWidget(self.eventDbusArgs)
         inputFieldHBox.addWidget(self.eventExec)
         inputFieldHBox.addWidget(self.eventBuiltin)
+        inputFieldHBox.addWidget(self.eventProfile)
         newEventVBox = QtGui.QVBoxLayout(self)
         newEventVBox.addLayout(dateHBox)
         newEventVBox.addLayout(nameAddHBox)
@@ -201,6 +203,7 @@ class DataCounterResetter(QtGui.QWidget):
         
         # If we're editing, adjust the GUI to the right values
         if (editing):
+            self.newEventDialog.setWindowTitle("Edit event")
             self.addButton.setText("Edit")
             self.intervalPicker.setCurrentIndex(
              self.eventList.currentItem().eventInfo["intervalIndex"])
@@ -255,12 +258,48 @@ class DataCounterResetter(QtGui.QWidget):
                 self.eventBuiltin.setCurrentIndex(
                  self.eventList.currentItem().eventInfo["builtinIndex"])
                 self.eventBuiltin.show()
+            elif self.eventList.currentItem().eventInfo["type"] == (
+                                                      profile_type):
+                self.populateProfilePicker()
+                i = self.eventProfile.findText(
+                 self.eventList.currentItem().eventInfo["content"])
+                if i == -1:
+                    self.showError('''<font color="#000000">This event has become invalid because tweakr is not installed!</font>''')
+                self.eventProfile.setCurrentIndex(i)
+                self.eventProfile.show()
             self.eventName.setText(
              self.eventList.currentItem().eventInfo["title"])
             self.editing = True
         
         self.newEventDialog.open()
     
+    def populateProfilePicker(self):
+        # check if tweakr is installed to choose profile type
+        try:
+            state = subprocess.Popen(['dpkg-query', '-l', 'tweakr'], 
+                             stdout=subprocess.PIPE).communicate(
+                             )[0].split("\n")[5].split()[0]
+        except IndexError:
+            state = "nope"
+        if state == "ii": # tweakr apparently is installed
+            self.tweakr = True
+            self.profiles = []
+            tweaker_profiles = subprocess.Popen(
+                    ['gconftool-2', '--all-dirs', '/system/tweakr'],
+                    stdout=subprocess.PIPE).communicate()[0].split("\n")
+            for profile in tweaker_profiles:
+                try:
+                    self.profiles.append(profile.split("/")[3])
+                except IndexError:
+                    pass
+        else:
+            self.tweakr = False
+            self.profiles = ["General"]
+        self.profiles.append("Silent")
+        for p in self.profiles:
+            self.eventProfile.addItem(p)
+        
+    
     def generateEventString(self, eventInfo):
         dateTime = QtCore.QDateTime.fromTime_t(eventInfo["ttime"])
         sdate = QtCore.QDate.fromString(dateTime.toString("ddMMyyyy"),
@@ -373,7 +412,8 @@ class DataCounterResetter(QtGui.QWidget):
             self.eventDbusName.hide()
             self.eventDbusArgs.hide()
             self.eventExec.hide()
-            self.eventBuiltin.hide()    
+            self.eventBuiltin.hide()  
+            self.eventProfile.hide()  
         elif type == dbus_type:
             self.eventBuiltin.hide()
             self.eventExec.hide()
@@ -382,6 +422,7 @@ class DataCounterResetter(QtGui.QWidget):
             self.eventDbusPath.show()
             self.eventDbusName.show()
             self.eventDbusArgs.show()
+            self.eventProfile.hide()
         elif type == exec_type:
             self.eventDbusInterface.hide()
             self.eventDbusService.hide()
@@ -390,6 +431,7 @@ class DataCounterResetter(QtGui.QWidget):
             self.eventDbusArgs.hide()
             self.eventBuiltin.hide()
             self.eventExec.show()
+            self.eventProfile.hide()
         elif type == builtin_type:
             self.eventDbusInterface.hide()
             self.eventDbusService.hide()
@@ -398,6 +440,17 @@ class DataCounterResetter(QtGui.QWidget):
             self.eventDbusArgs.hide()
             self.eventExec.hide()
             self.eventBuiltin.show()
+            self.eventProfile.hide()
+        elif type == profile_type:
+            self.eventDbusInterface.hide()
+            self.eventDbusService.hide()
+            self.eventDbusPath.hide()
+            self.eventDbusName.hide()
+            self.eventDbusArgs.hide()
+            self.eventExec.hide()
+            self.eventBuiltin.hide()
+            self.eventProfile.show()
+            self.populateProfilePicker()
 
     def showError(self, msg=""):
         ###pyside###
@@ -466,6 +519,8 @@ class DataCounterResetter(QtGui.QWidget):
             content = str(self.eventExec.text())
         elif type == builtin_type:
             content = str(self.eventBuiltin.currentText())
+        elif type == profile_type:
+            content = str(self.eventProfile.currentText())
         
         eventInfo = {}
         eventInfo["interval"] = str(self.intervalPicker.currentText())
@@ -518,15 +573,22 @@ class DataCounterResetter(QtGui.QWidget):
             action.flags |= (alarm.ACTION_WHEN_TRIGGERED | 
                              alarm.ACTION_TYPE_EXEC)
             if eventInfo["content"] == gprsdataresetter:
-                action.command = str("/opt/alarmed/gprsdataresetter.py")
+                action.command = str("/opt/alarmed/gprsdataresetter.sh")
             elif eventInfo["content"] == offlineswitcher:
-                action.command = str("/opt/alarmed/offlineswitcher.py")
+                action.command = str("/bin/ash -c '/opt/alarmed/onlineswitcher.sh offline'")
             elif eventInfo["content"] == onlineswitcher:
-                action.command = str("/opt/alarmed/onlineswitcher.py")
-            elif eventInfo["content"] == silentprofile:
-                action.command = str("/bin/ash -c '/opt/alarmed/profileswitcher.py silent'")
-            elif eventInfo["content"] == generalprofile:
-                action.command = str("/bin/ash -c '/opt/alarmed/profileswitcher.py general'")
+                action.command = str("/bin/ash -c '/opt/alarmed/onlineswitcher.sh normal'")
+                
+        elif eventInfo["type"] == profile_type:
+            action = event.add_actions(1)[0]
+            action.flags |= (alarm.ACTION_WHEN_TRIGGERED | 
+                             alarm.ACTION_TYPE_EXEC)
+            if eventInfo["content"] == "Silent":
+                action.command = str("/bin/ash -c '/opt/alarmed/profileswitcher.sh silent'")
+            elif self.tweakr:
+                action.command = str("/bin/ash -c '/opt/alarmed/tweakrprofileswitcher.sh " + eventInfo["content"] + "'")
+            else:
+                action.command = str("/bin/ash -c '/opt/alarmed/profileswitcher.sh general'")
             
         if eventInfo["interval"] != only_once:
             recurrence = event.add_recurrences(1)[0]
